%global toolchain clang

Name:		castxml
Version:	0.6.11
Release:	%mkrel 3
Summary:	C-family abstract syntax tree XML output tool
Group:		Development/C

License:	ASL 2.0
URL:		https://github.com/CastXML/CastXML
Source0:	https://github.com/CastXML/CastXML/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	llvm-devel
BuildRequires:	clang-devel
BuildRequires:	pkgconfig(libedit)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	python3dist(sphinx)
Obsoletes:	gccxml < 0.9.0-0.28

%description
Parse C-family source files and optionally write a subset of the
Abstract Syntax Tree (AST) to a representation in XML.

Source files are parsed as complete translation units using the clang
compiler. XML output is enabled by the --castxml-gccxml option and
produces a format close to that of gccxml. Future versions of castxml
may support alternative output formats.

%prep
%setup -q -n CastXML-%{version}

%build
%cmake -DCastXML_INSTALL_DOC_DIR:STRING=share/doc/%{name} \
       -DCastXML_INSTALL_MAN_DIR:STRING=share/man \
       -DCLANG_RESOURCE_DIR:PATH=$(clang -print-file-name=include)/.. \
       -DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
       -DCLANG_LINK_CLANG_DYLIB:BOOL=ON \
       -DBUILD_TESTING:BOOL=ON \
       -DSPHINX_MAN:BOOL=ON
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_defaultdocdir}/%{name}/LICENSE
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/NOTICE

%check
%ctest

%files
%{_bindir}/castxml
%doc %{_mandir}/man1/castxml.1*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/clang
%{_datadir}/%{name}/detect_vs.c
%{_datadir}/%{name}/detect_vs.cpp
%{_datadir}/%{name}/empty.c
%{_datadir}/%{name}/empty.cpp
%license LICENSE NOTICE


%changelog
* Wed Apr 30 2025 wally <wally> 0.6.11-3.mga10
+ Revision: 2180153
- build using clang toolchain
- rebuild for llvm 20.1.3

* Wed Feb 12 2025 daviddavid <daviddavid> 0.6.11-1.mga10
+ Revision: 2148108
- new version: 0.6.11

* Sat Nov 30 2024 daviddavid <daviddavid> 0.6.10-1.mga10
+ Revision: 2120053
- new version: 0.6.10

* Sun Nov 17 2024 wally <wally> 0.6.8-2.mga10
+ Revision: 2117139
- rebuild for LLVM 19.1.3

* Wed Jul 31 2024 daviddavid <daviddavid> 0.6.8-1.mga10
+ Revision: 2083036
- new version: 0.6.8

* Fri Jul 05 2024 daviddavid <daviddavid> 0.6.7-1.mga10
+ Revision: 2080015
- new version: 0.6.7

* Mon May 27 2024 daviddavid <daviddavid> 0.6.6-1.mga10
+ Revision: 2067880
- new version: 0.6.6

* Tue Apr 23 2024 daviddavid <daviddavid> 0.6.5-1.mga10
+ Revision: 2060547
- new version: 0.6.5

* Sun Mar 31 2024 daviddavid <daviddavid> 0.6.4-2.mga10
+ Revision: 2053387
- rebuild for new llvm/clang 17

* Wed Feb 14 2024 daviddavid <daviddavid> 0.6.4-1.mga10
+ Revision: 2041065
- new version: 0.6.4

* Fri Sep 29 2023 daviddavid <daviddavid> 0.6.2-1.mga10
+ Revision: 1992076
- new version: 0.6.2

* Fri Sep 01 2023 daviddavid <daviddavid> 0.6.1-1.mga10
+ Revision: 1983300
- new version: 0.6.1

* Wed Dec 28 2022 daviddavid <daviddavid> 0.5.1-1.mga9
+ Revision: 1927292
- new version: 0.5.1

* Thu Dec 08 2022 daviddavid <daviddavid> 0.5.0-1.mga9
+ Revision: 1919412
- new version: 0.5.0

* Sun Nov 20 2022 daviddavid <daviddavid> 0.4.7-1.mga9
+ Revision: 1909599
- new version: 0.4.7

* Tue Sep 27 2022 neoclust <neoclust> 0.4.6-1.mga9
+ Revision: 1892664
- New version 0.4.6

* Thu Sep 22 2022 tv <tv> 0.4.4-4.mga9
+ Revision: 1891437
- Rebuild for llvm-15

* Sat Apr 02 2022 tv <tv> 0.4.4-3.mga9
+ Revision: 1840354
- Rebuild for llvm-14

* Thu Mar 31 2022 umeabot <umeabot> 0.4.4-2.mga9
+ Revision: 1837173
- Mageia 9 Mass Rebuild

* Fri Jan 14 2022 mrambo3501 <mrambo3501> 0.4.4-1.mga9
+ Revision: 1768300
- version 0.4.4

* Thu Oct 21 2021 tv <tv> 0.4.3-2.mga9
+ Revision: 1752508
- Rebuild for llvm 13.0

* Mon Mar 08 2021 daviddavid <daviddavid> 0.4.3-1.mga9
+ Revision: 1700595
- new version: 0.4.3

* Thu Mar 04 2021 daviddavid <daviddavid> 0.4.2-1.mga9
+ Revision: 1697969
- new version: 0.4.2

* Tue Mar 02 2021 tv <tv> 0.3.6-3.mga9
+ Revision: 1695897
- rebuild for llvm/clang-12

* Thu Nov 26 2020 tv <tv> 0.3.6-2.mga8
+ Revision: 1649611
- rebuild for llvm/clang 11.0

* Thu Nov 19 2020 daviddavid <daviddavid> 0.3.6-1.mga8
+ Revision: 1647627
- new version: 0.3.6

* Mon May 25 2020 daviddavid <daviddavid> 0.3.4-1.mga8
+ Revision: 1587507
- new version: 0.3.4

* Wed Apr 22 2020 daviddavid <daviddavid> 0.3.3-1.mga8
+ Revision: 1570622
- new version: 0.3.3

* Sun Mar 22 2020 tv <tv> 0.3.1-2.mga8
+ Revision: 1558786
- rebuild with llvm 10

* Sun Mar 01 2020 daviddavid <daviddavid> 0.3.1-1.mga8
+ Revision: 1552692
- new version: 0.3.1
+ wally <wally>
- build with new cmake macros

* Tue Sep 17 2019 tv <tv> 0.1-0.14.20190117git9c91919.3.mga8
+ Revision: 1443066
- rebuild for llvm-9.0

* Sat Aug 17 2019 wally <wally> 0.1-0.14.20190117git9c91919.2.mga8
+ Revision: 1429495
- update sphinx BR

* Tue Apr 16 2019 daviddavid <daviddavid> 0.1-0.14.20190117git9c91919.1.mga7
+ Revision: 1391510
- new git snapshot (supports for LLVM8)
- drop castxml-shared.patch in favor of new LLVM_LINK_LLVM_DYLIB cmake option
- rebuild for new llvm/clang 8.0

* Thu Sep 27 2018 tv <tv> 0.1-0.14.20161006gitae93121.7.mga7
+ Revision: 1308165
- New git snapshot (supports LLVM7)
- Remove BuildRequires on llvm-static - llvm's cmake files have been fixed

* Sat Sep 22 2018 umeabot <umeabot> 0.1-0.14.20161006git05db76f.6.mga7
+ Revision: 1295994
- Mageia 7 Mass Rebuild

* Wed Apr 11 2018 tv <tv> 0.1-0.14.20161006git05db76f.5.mga7
+ Revision: 1217625
- rebuild with llvm-6

* Sat Nov 11 2017 tv <tv> 0.1-0.14.20161006git05db76f.4.mga7
+ Revision: 1176866
- rebuild with llvm-5

* Thu Sep 28 2017 daviddavid <daviddavid> 0.1-0.14.20161006git05db76f.3.mga7
+ Revision: 1161152
- fix files list

* Thu Sep 21 2017 tv <tv> 0.1-0.14.20161006git05db76f.2.mga7
+ Revision: 1156931
- rebuild with llvm-4.0 in core/release

* Sat Jan 07 2017 luigiwalser <luigiwalser> 0.1-0.14.20161006git05db76f.1.mga6
+ Revision: 1080519
- update to 20161006 snapshot (from fedora)
+ tmb <tmb>
- rebuild with new llvm

* Mon Mar 14 2016 tv <tv> 0.1-0.7.20150924git552dd69.1.mga6
+ Revision: 990572
- BR llvm-static
- rebuild for new llvm

* Wed Jan 06 2016 tmb <tmb> 0.1-0.7.20150924git552dd69.mga6
+ Revision: 920079
- rebuild for new llvm

* Thu Oct 29 2015 tv <tv> 0.1-0.6.20150924git552dd69.mga6
+ Revision: 896372
- imported package castxml


* Thu Oct 29 2015 Thierry Vignaud <tv@mageia.org> 0.1-0.6.20150924git552dd69.mga6
- import from FC
